@@ -36,7 +36,7 @@
 
 /* Defines the poppler version. */
 #ifndef POPPLER_VERSION
-#define POPPLER_VERSION "23.12.0"
+#define POPPLER_VERSION "24.11.0"
 #endif
 
 /* Use single precision arithmetic in the Splash backend */
@@ -66,12 +66,12 @@
 
 /* Build against libtiff. */
 #ifndef ENABLE_LIBTIFF
-/* #undef ENABLE_LIBTIFF */
+#define ENABLE_LIBTIFF 1
 #endif
 
 /* Build against libpng. */
 #ifndef ENABLE_LIBPNG
-/* #undef ENABLE_LIBPNG */
+#define ENABLE_LIBPNG 1
 #endif
 
 /* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'.
@@ -117,7 +117,7 @@
 //------------------------------------------------------------------------
 
 // copyright notice
-#define popplerCopyright "Copyright 2005-2023 The Poppler Developers - http://poppler.freedesktop.org"
+#define popplerCopyright "Copyright 2005-2024 The Poppler Developers - http://poppler.freedesktop.org"
 #define xpdfCopyright "Copyright 1996-2011, 2022 Glyph & Cog, LLC"
 
 //------------------------------------------------------------------------
